/*
 *  ngtk/c/ngtk_boxes.c
 *
 *  Copyright (C) 1998, 1999 Gabriel Fort <gabx@tfz.net>
 *
 */

/*----------------------------------------------------------------------------

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the 
    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
    Boston, MA  02111-1307  USA.

----------------------------------------------------------------------------*/
#include <ngtk/ngtk.h>

/* makes a 3d looking minibox in the specified ngtk_win_t window
 * This function is the base of the 3d look in Ngtk.
 * I makes a 3d border of (height, width), placed in (top, left).
 * If show is zero, the box will instead be erased.
 * Up is there to choose where to place the shadows, in order to make the
 * box going up or going down.
 * If refresh is set, the box will be immediately refreshed, else it won't
 * be until the next call to doupdate().
 */
void ngtk_minibox(ngtk_win_t *cur_win, /* The window to 'boxify' */
                  int height,          /* Height of the border */
                  int width,           /* Width of the border */
                  int top,             /* Y coordinate of the border, relative to *cur_win coordinates */
                  int left,            /* X coordinate of the border, relative to *cur_win coordinates */
                  int show,            /* Show the box if 1, erase it if 0 */
                  int up,              /* Makes the box going out of the display if 1, going in if 0 */
                  int refresh          /* Refresh immediately if 1, wait the next doupdate if 0 */);

/* makes a 3d boxed window
 * This function pushs a ngtk_win_t window on the stack, draws an upward 3d box,
 * and returns a pointer to this window.
 * returns a pointer to the created ngtk_win_t.
 */
ngtk_win_t *ngtk_mkbox(int height, /* Height of the window */
                       int width, /* Width of the window */
                       int top, /* Top/left Y coordinate, relative to the entire display */
                       int left, /* Top/left X coordinate, relative to the entire display */
                       int cpair, /* Color pair for the window */
                       int attr, /* Attributes for the window */
                       char *title, /* title of the box (may be NULL) */
                       int echo, /* Echo cursor if 1, invisible if 0 */
                       int shadow, /* Shadowed window if 1, no shadow if 0 */
                       int refresh /* Refresh immediately if 1, wait the next doupdate if 0 */);

